# AUTOGENERATED! DO NOT EDIT! File to edit: 02_jpinfo.ipynb (unless otherwise specified).

__all__ = ['prefectures', 'prefectures_short_names', 'prefectures_short2full', 'prefectures_code2name',
           'prefectures_name2code']

# Cell
prefectures = [
    "北海道",
    "青森県",
    "岩手県",
    "宮城県",
    "秋田県",
    "山形県",
    "福島県",
    "茨城県",
    "栃木県",
    "群馬県",
    "埼玉県",
    "千葉県",
    "東京都",
    "神奈川県",
    "新潟県",
    "富山県",
    "石川県",
    "福井県",
    "山梨県",
    "長野県",
    "岐阜県",
    "静岡県",
    "愛知県",
    "三重県",
    "滋賀県",
    "京都府",
    "大阪府",
    "兵庫県",
    "奈良県",
    "和歌山県",
    "鳥取県",
    "島根県",
    "岡山県",
    "広島県",
    "山口県",
    "徳島県",
    "香川県",
    "愛媛県",
    "高知県",
    "福岡県",
    "佐賀県",
    "長崎県",
    "熊本県",
    "大分県",
    "宮崎県",
    "鹿児島県",
    "沖縄県",
]

# Cell
prefectures_short_names = [p[:-1] for p in prefectures]

# Cell
prefectures_short2full = { s:f for s,f in zip(prefectures_short_names, prefectures) }

# Cell
prefectures_code2name = {
    code: name
    for name, code in zip(prefectures, range(1, 1 + len(prefectures)))
}

# Internal Cell
_prefectures_name2code = {
    name: code
    for name, code in zip(prefectures, range(1, 1 + len(prefectures)))
}

# Cell
prefectures_name2code = {
    **_prefectures_name2code,
    **{
        sn: _prefectures_name2code[prefectures_short2full[sn]]
        for sn in prefectures_short_names
    },
}